/*============================================================================
  File:     RestoreCredit.sql

  Summary:  Restore the Credit Database to give us a clean start between demos.
  
		    **************************************	
		    ***	NOTE: THIS IS A SQLCMD SCRIPT! ***
		    **************************************	
		
		    Be sure to turn that on before running as well as modify the parameters
		    for the connection and restore directories.
  
  SQL Server Version: 2008/2008 R2/2012
------------------------------------------------------------------------------
  Written by SQLskills.com

  For more scripts and sample code, check out http://www.SQLskills.com

  This script is intended only as a supplement to demos and lectures
  given by Kimberly L. Tripp.  
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- These samples use the Credit database. You can download and restore the
-- credit database from here:
-- http://www.sqlskills.com/sql-server-resources/sql-server-demos/ 

-- NOTE: You can use a SQL Server 2000 back and restore to: 2000, 2005 or 2008/R2
-- There's also a 2008 backup that you can restore to 2008/R2 or 2012

-- IMPORTANT NOTES: 
-- 1) All examples expect a database name of Credit. However, if you
--    already have a database with this name, you can change it. In all other
--    scripts, you'll need to be sure to continue to change this based on your
--    new database name. (Line 54)
-- 2) Be sure to set your complete path\file based on where the 
--    backup is located. (LINE 55)
-- 3) Be sure to set the server/instance name for restore. (LINE 56)
-- 4) Be sure to set your instance directory structure based on your
--    installation. (LINES 58-60)

-- In general, this script should take less than 30 seconds to execute.

:ON ERROR EXIT
go

:SETVAR DB Credit
:SETVAR CreditBackup "D:\SQLskills\CreditBackup100.BAK"
:SETVAR RestoreToServer (local)\SQL2012Dev01

--:SETVAR RestoreToDirectory "C:\Program Files\Microsoft SQL Server\MSSQL10.SQLDev01\MSSQL\data"
--:SETVAR RestoreToDirectory "C:\Program Files\Microsoft SQL Server\MSSQL10_50.SQL2008R2Dev01\MSSQL\data"
:SETVAR RestoreToDirectory "D:\Microsoft SQL Server\MSSQL11.SQL2012Dev01\MSSQL\data"
go

:CONNECT $(RestoreToServer)
go

SET NOCOUNT ON
go

USE master
go

IF DATABASEPROPERTYEX('$(DB)', 'Collation') IS NOT NULL
	ALTER DATABASE [$(DB)]
		SET RESTRICTED_USER 
		WITH ROLLBACK IMMEDIATE
go

IF substring(convert(varchar, SERVERPROPERTY('ProductVersion')), 1, 2) >= '10' 
	RESTORE DATABASE [$(DB)] 
	FROM  DISK = N'$(CreditBackup)' 
	WITH  FILE = 1,  
		MOVE N'CreditData' 
			TO N'$(RestoreToDirectory)\CreditData.mdf',  
		MOVE N'CreditLog' 
			TO N'$(RestoreToDirectory)\CreditLog.ldf',
	STATS = 10, REPLACE
go

IF DATABASEPROPERTYEX('$(DB)', 'Collation') IS NOT NULL
	ALTER DATABASE [$(DB)]
		SET MULTI_USER 
		WITH ROLLBACK IMMEDIATE
go